pub enum AddEntityError {
ChunkNotLoaded {
entity_id: i32,
chunk: ChunkPos,
},
DuplicateUuid {
entity_id: i32,
uuid: Uuid,
},
RemovedEntity {
entity_id: i32,
},
}Expand description
Error returned when adding an entity to the runtime world fails.
Variants
ChunkNotLoaded
The entity is in a chunk that is not active in the world entity manager.
DuplicateUuid
Another live entity with the same persistent UUID is already registered.
RemovedEntity
The entity is already removed and cannot be added to the live world.