pub(crate) fn get_kill_credit<E: LivingEntity + ?Sized>(
entity: &E,
world: &World,
) -> Option<SharedEntity>Expand description
Returns the living entity that will be credited with killing this entity.
pub(crate) fn get_kill_credit<E: LivingEntity + ?Sized>(
entity: &E,
world: &World,
) -> Option<SharedEntity>Returns the living entity that will be credited with killing this entity.