pub struct EntityMoveUpdate {
pub entity_id: i32,
pub old_section: SectionPos,
pub new_section: SectionPos,
pub old_chunk: ChunkPos,
pub new_chunk: ChunkPos,
pub old_accessible: bool,
pub new_accessible: bool,
pub old_ticking: bool,
pub new_ticking: bool,
}Expand description
Section/chunk membership update caused by a committed entity move.
Fields
entity_id: i32Entity network ID.
old_section: SectionPosPrevious section membership.
new_section: SectionPosNew section membership.
old_chunk: ChunkPosPrevious chunk membership.
new_chunk: ChunkPosNew chunk membership.
old_accessible: boolWhether the entity was visible to normal world/tracker queries before the move.
new_accessible: boolWhether the entity is visible to normal world/tracker queries after the move.
old_ticking: boolWhether the manager-owned entity was in the tick list before the move.
new_ticking: boolWhether the manager-owned entity is in the tick list after the move.
Implementations
Sourceimpl EntityMoveUpdate
impl EntityMoveUpdate
Sourcepub fn section_changed(&self) -> bool
pub fn section_changed(&self) -> bool
Returns whether the entity changed sections.
Sourcepub fn chunk_changed(&self) -> bool
pub fn chunk_changed(&self) -> bool
Returns whether the entity changed chunks.
Sourcepub const fn accessibility_changed(&self) -> bool
pub const fn accessibility_changed(&self) -> bool
Returns whether the entity crossed an accessibility boundary.
Sourcepub const fn became_accessible(&self) -> bool
pub const fn became_accessible(&self) -> bool
Returns whether this move made a previously hidden entity accessible.
Sourcepub const fn became_inaccessible(&self) -> bool
pub const fn became_inaccessible(&self) -> bool
Returns whether this move made a previously accessible entity hidden.
Sourcepub const fn became_ticking(&self) -> bool
pub const fn became_ticking(&self) -> bool
Returns whether this move made a previously non-ticking entity tick.
Sourcepub const fn became_non_ticking(&self) -> bool
pub const fn became_non_ticking(&self) -> bool
Returns whether this move made a previously ticking entity stop ticking.