pub struct EntityMovementFlags {
on_ground: bool,
horizontal_collision: bool,
vertical_collision: bool,
vertical_collision_below: bool,
}Expand description
Vanilla collision and ground-contact flags updated by Entity.move.
Fields
on_ground: boolhorizontal_collision: boolvertical_collision: boolvertical_collision_below: boolImplementations
Sourceimpl EntityMovementFlags
impl EntityMovementFlags
Sourcepub fn after_move(
on_ground: bool,
horizontal_collision: bool,
vertical_collision: bool,
requested_delta: DVec3,
) -> Self
pub fn after_move( on_ground: bool, horizontal_collision: bool, vertical_collision: bool, requested_delta: DVec3, ) -> Self
Creates movement flags from a completed movement pass.
Sourcepub fn after_move_with_previous(
previous: Self,
vertical_state_update: EntityVerticalMovementStateUpdate,
on_ground: bool,
horizontal_collision: bool,
vertical_collision: bool,
requested_delta: DVec3,
) -> Self
pub fn after_move_with_previous( previous: Self, vertical_state_update: EntityVerticalMovementStateUpdate, on_ground: bool, horizontal_collision: bool, vertical_collision: bool, requested_delta: DVec3, ) -> Self
Creates movement flags from a completed movement pass while preserving vertical/ground state when vanilla skips that update.
Sourcepub const fn horizontal_collision(self) -> bool
pub const fn horizontal_collision(self) -> bool
Returns true if the last movement was clipped horizontally.
Sourcepub const fn vertical_collision(self) -> bool
pub const fn vertical_collision(self) -> bool
Returns true if the last movement was clipped vertically.
Sourcepub const fn vertical_collision_below(self) -> bool
pub const fn vertical_collision_below(self) -> bool
Returns true if the last vertical collision was below the entity.
Sourcepub const fn with_on_ground(self, on_ground: bool) -> Self
pub const fn with_on_ground(self, on_ground: bool) -> Self
Returns the same flags with a new ground-contact value.
Sourcepub const fn with_horizontal_collision(self, horizontal_collision: bool) -> Self
pub const fn with_horizontal_collision(self, horizontal_collision: bool) -> Self
Returns the same flags with a new horizontal-collision value.
Sourcepub const fn without_collisions(self) -> Self
pub const fn without_collisions(self) -> Self
Returns the same ground state with collision flags cleared.