MobEffectInstance

Struct MobEffectInstance 

pub struct MobEffectInstance {
    effect: MobEffectRef,
    duration: i32,
    amplifier: i32,
    ambient: bool,
    visible: bool,
    show_icon: bool,
    hidden_effect: Option<Box<MobEffectInstance>>,
}
Runtime mob-effect state.

Mirrors vanilla MobEffectInstance state that affects server-side living physics and client synchronization.

Fields

effect: MobEffectRefduration: i32amplifier: i32ambient: boolvisible: boolshow_icon: boolhidden_effect: Option<Box<MobEffectInstance>>

Implementations

Source

impl MobEffectInstance

pub const fn new(effect: MobEffectRef, amplifier: i32) -> Self

Creates infinite active mob-effect state for internal physics tests and hooks.

pub const fn with_duration( effect: MobEffectRef, duration: i32, amplifier: i32, ) -> Self

Creates active mob-effect state with vanilla default visibility flags.

pub const fn with_ambient(self, ambient: bool) -> Self

Sets whether this effect is ambient.

pub const fn with_visible(self, visible: bool) -> Self

Sets whether this effect should show particles.

pub const fn with_show_icon(self, show_icon: bool) -> Self

Sets whether this effect should show its inventory icon.

pub const fn effect(&self) -> MobEffectRef

Returns the mob effect.

pub const fn duration(&self) -> i32

Returns vanilla MobEffectInstance.getDuration().

pub const fn amplifier(&self) -> i32

Returns vanilla MobEffectInstance.getAmplifier().

pub const fn is_ambient(&self) -> bool

Returns vanilla MobEffectInstance.isAmbient().

pub const fn is_visible(&self) -> bool

Returns vanilla MobEffectInstance.isVisible().

pub const fn show_icon(&self) -> bool

Returns vanilla MobEffectInstance.showIcon().

pub const fn is_infinite_duration(&self) -> bool

Returns whether this effect uses vanilla’s infinite-duration sentinel.

pub(crate) fn to_vanilla_nbt(&self) -> NbtCompound

Serializes this effect with vanilla’s MobEffectInstance.CODEC shape.

fn details_to_vanilla_nbt(&self) -> NbtCompound

pub(crate) const fn has_remaining_duration(&self) -> bool

pub(crate) fn should_apply_effect_tick_this_tick( &self, entity_tick_count: i32, ) -> bool

pub(crate) fn apply_effect_tick<E: LivingEntity + ?Sized>( &self, world: &World, entity: &E, ) -> bool

const fn is_shorter_duration_than(&self, other: &Self) -> bool

pub fn update(&mut self, take_over: Self) -> bool

Merges another instance of the same effect into this instance.

Mirrors vanilla MobEffectInstance.update.

fn tick_duration(&mut self) -> MobEffectTickResult

fn tick_down_duration(&mut self)

fn downgrade_to_hidden_effect(&mut self) -> bool